@@ -1,27 +1,15 @@
 from argparse import ArgumentParser
+from dotenv import load_dotenv
 import os
 import platform
 import re
 import random
 import fnmatch
 
-
-class bcolors:
-    """It's a class that contains a bunch of variables that are strings of ANSI escape codes.
-    Example:
-        ```
-        Colors.HEADER
-        Colors.OKBLUE
-        Colors.OKGREEN
-        Colors.WARNING
-        Colors.FAIL
-        Colors.ENDC
-        ```
-    Return:
-        None
-    """
+load_dotenv()
 
 
+# It's a class that contains a bunch of constants that represent colors.
 class Colors:
     ESCAPE_SEQ = {
         "HEADER": "\033[95m",
@@ -362,9 +350,7 @@ Include information about the license used for the project, such as the name of
 
 """
         with open(markdown_path, "w", encoding="utf-8") as f:
-            f.write(
-                markdown.format(name, name, name, env_directory(), generate_tree("."))
-            )
+            f.write(markdown.format(name, name, name, name, generate_tree(".")))
         os.chmod(markdown_path, 0o777)
         print(notice + f'Successfully created the file "{markdown_path}"')
 
@@ -417,7 +403,7 @@ Include information about the license used for the project, such as the name of
 {}
 ```
 """.format(
-                    env_directory(), generate_tree(".")
+                    name, generate_tree(".")
                 )
         with open(markdown_path, "w", encoding="utf-8") as f:
             f.writelines(data)
@@ -750,7 +736,7 @@ def run_cmd_new(args):
         print(
             "Maybe you forgot to enter the name of the folder? for example"
             + " `"
-            + Colors.MINTGREEN
+            + Colors.LIGHTGREEN_EX
             + "fenv new"
             + Colors.NAVY
             + " <project_folder>"
@@ -798,7 +784,7 @@ def run_cmd_install(args):
                     break
     except AttributeError as err:
         print(
-            Colors.MINTGREEN
+            Colors.LIGHTGREEN_EX
             + "An error was encountered, it could not be installed."
             + Colors.ENDC
         )
@@ -826,10 +812,10 @@ def install_package_all():
     def run_install_main(folder_name_env):
         if folder_name_env:
             print(
-                f"Found directory  `{Colors.MINTGREEN}{folder_name_env}{Colors.ENDC}`"
+                f"Found directory  `{Colors.LIGHTGREEN_EX}{folder_name_env}{Colors.ENDC}`"
             )
             print(
-                f"Installing modules with  `{Colors.MINTGREEN}{folder_name_env}{Colors.ENDC}`"
+                f"Installing modules with  `{Colors.LIGHTGREEN_EX}{folder_name_env}{Colors.ENDC}`"
             )
             install_package_follow_env(folder_name_env)
             print(notice + f'Successfully installed module from "requirements.txt"')
@@ -849,7 +835,7 @@ def install_package_all():
                         fnmatch.filter(os.listdir("."), folder_name)[0]
                     )
                     print(
-                        f"Installing modules with  `{Colors.MINTGREEN}{folder_name_env}{Colors.ENDC}`"
+                        f"Installing modules with  `{Colors.LIGHTGREEN_EX}{folder_name_env}{Colors.ENDC}`"
                     )
                     install_package_follow_env(folder_name_env)
                     print(
@@ -865,7 +851,7 @@ def install_package_all():
         run_install_main(folder_name_env)
     else:
         print(
-            f"Maybe you forgot to put the name of the package to ininstall? for example `{Colors.MINTGREEN}fenv ininstall{Colors.OKBLUE} <package_name>{Colors.ENDC}` \nOr you can use `{Colors.MINTGREEN}fenv ininstall{Colors.ENDC}` alone. But there must be {Colors.FAIL}{requirements_file}{Colors.ENDC} in the current directory"
+            f"Maybe you forgot to put the name of the package to ininstall? for example `{Colors.LIGHTGREEN_EX}fenv ininstall{Colors.OKBLUE} <package_name>{Colors.ENDC}` \nOr you can use `{Colors.LIGHTGREEN_EX}fenv ininstall{Colors.ENDC}` alone. But there must be {Colors.FAIL}{requirements_file}{Colors.ENDC} in the current directory"
         )
 
 
@@ -954,7 +940,7 @@ def run_cmd_onlyenv():
         print(notice + f'Successfully created the virtualenv "{virtual_env_name}"')
 
     _name_env = create_name_env()
-    print(f"your env name is `{Colors.MINTGREEN}{_name_env}{Colors.ENDC}`")
+    print(f"your env name is `{Colors.LIGHTGREEN_EX}{_name_env}{Colors.ENDC}`")
     create_virtualenv(_name_env)
     dir_name_only = os.path.basename(os.getcwd())  # get name dir main
     create_setting_vscode(dir_name_only)
@@ -993,7 +979,7 @@ def check_command(args):
         run_cmd_uninstall(args) if args.uninstall != None else print(
             "Maybe you forgot to put the name of the package to uninstall? for example"
             + " `"
-            + Colors.MINTGREEN
+            + Colors.LIGHTGREEN_EX
             + "fenv uninstall"
             + Colors.OKBLUE
             + " <package_name>"
@@ -1019,9 +1005,9 @@ def main():
         None
     """
     args = setup_parse()
-    version: str = "v0.0.11.5"
+    version: str = os.getenv("FENV_VERSION")
     print(
-        f"⏩ {Colors.LIGHTMAGENTA_EX}Hello,Fenv {Colors.POWDER_BLUE}[{Colors.MINT_GREEN}{version}{Colors.POWDER_BLUE}]{Colors.ENDC}🫡\n".center(
+        f"⏩ {Colors.LIGHTMAGENTA_EX}Hello,Fenv {Colors.POWDER_BLUE}[{Colors.MINT_GREEN}v{version}{Colors.POWDER_BLUE}]{Colors.ENDC}🫡\n".center(
             40, "-"
         )
     ) if args.__dict__["command"] == None else None
